@@ -6,7 +6,6 @@ processFormula <- function (formula, data, marginal, type = c("Discrete", "Conti
     }
     used.var <- get.var.of.type(type)
 
-
     if (!inherits(formula, "formula")) {
       formula <- list2rhsFormula(formula)
     }
@@ -53,68 +52,17 @@ processFormula <- function (formula, data, marginal, type = c("Discrete", "Conti
         charmatch(l, used.var)
     })
 
-    value <- list(formula = formula, str.formula = str.formula, num.formula = num.formula,
+    value <- list(formula = formula, str.formula = str.formula,
+                  num.formula = num.formula,
         list.formula = list.formula, gmData = data, varnames = used.var)
     value
 }
 
 
-## Turn a right-hand-sided formula into a list (anything on the left hand side is ignored)
-##
-## January 2011
-
-rhsFormula2list <- rhsf2list <- function(f){
-    if ( is.character( f ) ){
-        list( f )
-    } else {
-        if ( is.numeric( f ) ){
-            lapply( list( f ), "as.character" )
-        } else {
-            if ( is.list( f ) ){
-                lapply(f, "as.character")
-            } else {
-                ## We assume a formula...
-                ## FIXME: Was:   ##.xxx. <- f[[2]]
-                ## Changed to
-                .xxx. <- f[[ length( f ) ]]
-                f1 <- unlist(strsplit(paste(deparse(.xxx.), collapse="")," *\\+ *"))
-                f2 <- unlist(lapply(f1, strsplit, " *\\* *| *: *| *\\| *"),recursive=FALSE)
-                f2
-            }
-        }
-    }
-}
 
 
-
-## Turn list into right-hand-sided formula
-##
-## July 2008
-list2rhsFormula <- list2rhsf <- function(f){
-  if (inherits(f,"formula"))
-    return(f)
-  as.formula(paste("~",paste(unlist(lapply(f,paste, collapse='*')),collapse="+")),
-             .GlobalEnv)
-}
-
-allSubsets <- function(x,g.sep="+"){
-  if (length(x)==1)
-    return(x)
-  else {
-    val <- x[1]
-    for (i in 2:length(x)){
-      v <- paste(val,x[i],sep=g.sep)
-      val <- c(val,x[i],v)
-    }
-    val <- strsplit(val,paste("\\",g.sep,sep=""))
-    return(val)
-  }
-}
-
-selectOrder  <- function(x,order=2){
-  v <- allSubsets(x)
-  value <- v[lapply(v,length)==as.numeric(order)]
-  return(value)
+selectOrder  <- function(x, order=2){
+    combn_prim(x, order, simplify=FALSE)
 }
 
 extract.power<-function(fff){
@@ -368,7 +316,7 @@ readf <- function(s, v.sep="*", g.sep="+") {
   S <- ..varset(m)
   dr <- dual.rep(m, S)
   dr <- c(dr, list(edge))
-  removeRedundant(dual.rep(dr, S, FALSE))
+  remove_redundant(dual.rep(dr, S, FALSE))
 }
 
 #m2 <- readf('B.D+A.D+C.D')
@@ -390,7 +338,7 @@ readf <- function(s, v.sep="*", g.sep="+") {
   k <- length(dr)
   if (k>0) {for (i in 1:k) if (setequal(dr[[i]], edge)) dr[[i]] <- vector()}
 #  if (k>0) {for (i in 1:k) if (setequal(dr[[i]], edge)) dr[[i]] <- NULL}
-  dr <- removeRedundant(dr, FALSE)
+  dr <- remove_redundant(dr, FALSE)
   dual.rep(dr, S, FALSE)
 }
 
